@@ -16,7 +16,7 @@ pub enum PgAuthMethod {
 ///
 /// Postgresql server status
 ///
-#[derive(PartialEq)]
+#[derive(Debug, PartialEq)]
 pub enum PgServerStatus {
     /// Postgres uninitialized
     Uninitialized,
@@ -149,7 +149,7 @@ impl Default for Architecture {
 }
 
 /// The postgresql binaries acquisition status
-#[derive(Copy, Clone)]
+#[derive(Copy, Clone, PartialEq)]
 pub enum PgAcquisitionStatus{
     /// Acquiring postgresql binaries
     InProgress,
