@@ -124,7 +124,9 @@ impl PgEmbed {
             self.acquire_postgres().await?;
         }
         self.pg_access.create_password_file(self.pg_settings.password.as_bytes()).await?;
-        if !self.pg_access.db_files_exist().await? {
+        if self.pg_access.db_files_exist().await? {
+            self.server_status = PgServerStatus::Initialized;
+        } else {
             &self.init_db().await?;
         }
         Ok(())
@@ -310,7 +312,7 @@ impl PgEmbed {
     }
 
     ///
-    /// Check database existance
+    /// Check database existence
     ///
     #[cfg(any(feature = "rt_tokio_migrate", feature = "rt_async_std_migrate", feature = "rt_actix_migrate"))]
     pub async fn database_exists(&self, db_name: &str) -> Result<bool, PgEmbedError> {
